# `wap help`

`wap help [OPTIONS] [SUBCOMMAND]`

Open the help webpage for the given `COMMAND` in your browser.

If a browser is not available, simply print the URL to which you would be navigated.

!!! example

    `wap help help` will take you to _this_ webpage.

## Options

### `--help`

`--help`

Show the built-in help text and exit.
